Commit Diff


commit - f4e7405e309a640148eef4c8a266ce94c4a23b6d
commit + 24fcd3677c53c0e0fa39f72d741644b390339a00
blob - 610e69cacd582d67d25bb12662536703ab9cfc8d
blob + 08f6f115ecde37199461a23912c747b832fa2e04
--- regress/agent/run.sh
+++ regress/agent/run.sh
@@ -782,9 +782,9 @@ ok "agent usage: nested usage enters the final aggrega
 stop_stub
 
 # The status bar is a different projection from the whole-Turn aggregate:
 # after the same delegated Turn it contains only AGENTCALL and AGENTSYNTH.
 # Lead context is (13 + 1 + 14) + (25 + 1 + 8) = 62 tokens; including the
 # child's (21 + 1 + 7) would incorrectly display 91.
 rm -rf "$HOME/.fugu"
 start_stub AGENTCALL AGENTREPORT AGENTSYNTH
 write_conf
@@ -798,10 +798,10 @@ curses_ok=1
 [ "$rc" -eq 0 ] && curses_ok=0
 ok "agent usage: curses Turn completes" "$curses_ok"
 lead_context_ok=1
-grep -a -Fq "Context 62/200k 0%" "$dir/cursesout" && lead_context_ok=0
+grep -a -Fq "Context 34/200k 0%" "$dir/cursesout" && lead_context_ok=0
 ok "agent usage: child tokens stay out of Lead Context" "$lead_context_ok"
 aggregate_context_ok=0
-grep -a -Fq "Context 91/200k 0%" "$dir/cursesout" 2>/dev/null && \
+grep -a -Fq "Context 63/200k 0%" "$dir/cursesout" 2>/dev/null && \
     aggregate_context_ok=1
 ok "agent usage: whole-Turn aggregate is never shown as Lead Context" \
     "$aggregate_context_ok"
@@ -782,9 +782,9 @@ ok "agent usage: nested usage enters the final aggrega
 
 # The status bar is a different projection from the whole-Turn aggregate:
-# after the same delegated Turn it contains only AGENTCALL and AGENTSYNTH.
-# Lead context is (13 + 1 + 14) + (25 + 1 + 8) = 62 tokens; including the
-# child's (21 + 1 + 7) would incorrectly display 91.
+# after the same delegated Turn it contains only the latest committed Lead
+# Generation, AGENTSYNTH.  Its context is 25 + 1 + 8 = 34 tokens; including
+# the child's 21 + 1 + 7 would incorrectly display 63.
 rm -rf "$HOME/.fugu"
 start_stub AGENTCALL AGENTREPORT AGENTSYNTH